==> sodium-native-1.4.0.tgz: package/src/crypto_hash_sha256_wrap.cc <==
#include "crypto_hash_sha256_wrap.h"
#include "macros.h"

static Nan::Persistent<FunctionTemplate> crypto_hash_sha256_constructor;

CryptoHashSha256Wrap::CryptoHashSha256Wrap () {
  this->state = NULL;
}

CryptoHashSha256Wrap::~CryptoHashSha256Wrap () {
  sodium_free(this->state);
}

NAN_METHOD(CryptoHashSha256Wrap::New) {
  CryptoHashSha256Wrap* obj = new CryptoHashSha256Wrap();
  obj->Wrap(info.This());
  info.GetReturnValue().Set(info.This());
}

NAN_METHOD(CryptoHashSha256Wrap::Update) {
  CryptoHashSha256Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha256Wrap>(info.This());
  ASSERT_BUFFER_SET_LENGTH(info[0], input)
  crypto_hash_sha256_update(self->state, CDATA(input), input_length);
}

NAN_METHOD(CryptoHashSha256Wrap::Final) {
  CryptoHashSha256Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha256Wrap>(info.This());
  ASSERT_BUFFER_MIN_LENGTH(info[0], output, crypto_hash_sha256_BYTES)
  crypto_hash_sha256_final(self->state, CDATA(output));
}

void CryptoHashSha256Wrap::Init () {
  Local<FunctionTemplate> tpl = Nan::New<FunctionTemplate>(CryptoHashSha256Wrap::New);
  crypto_hash_sha256_constructor.Reset(tpl);
  tpl->SetClassName(Nan::New("CryptoHashSha256Wrap").ToLocalChecked());
  tpl->InstanceTemplate()->SetInternalFieldCount(1);

  Nan::SetPrototypeMethod(tpl, "update", CryptoHashSha256Wrap::Update);
  Nan::SetPrototypeMethod(tpl, "final", CryptoHashSha256Wrap::Final);
}

Local<Value> CryptoHashSha256Wrap::NewInstance () {
  Nan::EscapableHandleScope scope;

  Local<Object> instance;

  Local<FunctionTemplate> constructorHandle = Nan::New<FunctionTemplate>(crypto_hash_sha256_constructor);
  instance = Nan::NewInstance(constructorHandle->GetFunction()).ToLocalChecked();

  CryptoHashSha256Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha256Wrap>(instance);
  self->state = (crypto_hash_sha256_state*) sodium_malloc(crypto_hash_sha256_statebytes());
  crypto_hash_sha256_init(self->state);

  return scope.Escape(instance);
}

==> sodium-native-1.7.0.tgz: package/src/crypto_hash_sha256_wrap.cc <==
#include "crypto_hash_sha256_wrap.h"
#include "macros.h"

static Nan::Persistent<FunctionTemplate> crypto_hash_sha256_constructor;

CryptoHashSha256Wrap::CryptoHashSha256Wrap () {}

CryptoHashSha256Wrap::~CryptoHashSha256Wrap () {}

NAN_METHOD(CryptoHashSha256Wrap::New) {
  CryptoHashSha256Wrap* obj = new CryptoHashSha256Wrap();
  obj->Wrap(info.This());
  info.GetReturnValue().Set(info.This());
}

NAN_METHOD(CryptoHashSha256Wrap::Update) {
  CryptoHashSha256Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha256Wrap>(info.This());
  ASSERT_BUFFER_SET_LENGTH(info[0], input)
  crypto_hash_sha256_update(&(self->state), CDATA(input), input_length);
}

NAN_METHOD(CryptoHashSha256Wrap::Final) {
  CryptoHashSha256Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha256Wrap>(info.This());
  ASSERT_BUFFER_MIN_LENGTH(info[0], output, crypto_hash_sha256_BYTES)
  crypto_hash_sha256_final(&(self->state), CDATA(output));
}

void CryptoHashSha256Wrap::Init () {
  Local<FunctionTemplate> tpl = Nan::New<FunctionTemplate>(CryptoHashSha256Wrap::New);
  crypto_hash_sha256_constructor.Reset(tpl);
  tpl->SetClassName(Nan::New("CryptoHashSha256Wrap").ToLocalChecked());
  tpl->InstanceTemplate()->SetInternalFieldCount(1);

  Nan::SetPrototypeMethod(tpl, "update", CryptoHashSha256Wrap::Update);
  Nan::SetPrototypeMethod(tpl, "final", CryptoHashSha256Wrap::Final);
}

Local<Value> CryptoHashSha256Wrap::NewInstance () {
  Nan::EscapableHandleScope scope;

  Local<Object> instance;

  Local<FunctionTemplate> constructorHandle = Nan::New<FunctionTemplate>(crypto_hash_sha256_constructor);
  instance = Nan::NewInstance(constructorHandle->GetFunction()).ToLocalChecked();

  CryptoHashSha256Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha256Wrap>(instance);
  crypto_hash_sha256_init(&(self->state));

  return scope.Escape(instance);
}
